@@ -46,13 +46,10 @@ $boxed_lb->add($listbox, $buttons);
 # return of $main->mainloop will (usually) not be visible, but may
 # completely garble your output (by moving the cursor)!
 
-my $window;			# must be declared before the sub using it!
-$window =
-    $main->window({title => 'Listbox', width => 18, height => 19},
-		  $boxed_lb,
-		  UI::Various::Button->new
-		  (text => 'Quit',
-		   code => sub{   $window->destroy;   }));
+$main->window({title => 'Listbox', width => 18, height => 19},
+	      $boxed_lb,
+	      UI::Various::Button->new(text => 'Quit',
+				       code => sub{   $_[0]->destroy;   }));
 $main->mainloop;
 
 #########################################################################
